# oceanengine

#### 介绍
巨量引擎工具集

#### 软件架构
软件架构说明


#### 安装教程

1.  pip安装
```shell script
pip install oceanengine
```
2.  pip安装（使用阿里镜像加速）
```shell script
pip install oceanengine -i https://mirrors.aliyun.com/pypi/simple
```

#### 使用说明

1.  demo
```python
import oceanengine
test_res = oceanengine.ad_promote_ad_list(cookie='cookie', csrf_token='token', aadvid='')
```
